##  Listing All Fact Sheets with a Specific Subscription Type or Role
To list all fact sheets with a specific subscription type or role, do the following:
  1. In the Subscriptions filter group, select ‘n/a' to list all fact sheets without subscriptions.
  2. Select a subscription type or role from the drop-down list below. This lists all fact sheets without subscriptions of that type or role.
  3. From the filter group settings (gear icon), select IS NOT - none of the selected items. This inverts the previous list to show all fact sheets with that specific subscription type or role.


![Listing All Fact Sheets With a Specific Subscription Type or Role](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748e2c67a4410149da2f0361316a21e_LowRes.png)
Listing All Fact Sheets With a Specific Subscription Type or Role
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
